@@ -3,10 +3,10 @@
 from sys import stderr
 import calendar
 from math import floor
-from entities import Campaign, CustomVariable, Event, Item, Page, Session, SocialInteraction, Transaction, Visitor
+from pyga.entities import Campaign, CustomVariable, Event, Item, Page, Session, SocialInteraction, Transaction, Visitor
+import pyga.utils as utils
 import urllib
 import urllib2
-import utils
 
 __author__ = "Arun KR (kra3) <the1.arun@gmail.com>"
 __license__ = "Simplified BSD"
@@ -169,7 +169,7 @@ class Request(GIFRequest):
 
     def build_visitor_parameters(self, params):
         if self.visitor.locale:
-            params.utml = self.visitor.locale.replace('_', '-').lower()
+            params.utmul = self.visitor.locale.replace('_', '-').lower()
 
         if self.visitor.flash_version:
             params.utmfl = self.visitor.flash_version
